ChessState class

Constructors

ChessState(String fen, {ChessState? last})

Properties

board ↔ Map<int, Map<int, StateEntry>>
latefinal
fen → String
final
hashCode → int
The hash code for this object.
no setterinherited
last → ChessState?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findFrom(String piece) → SquarePosition?
getDelta(String piece, String lastPiece) → StateEntryDelta
getEntry(int rank, int file) → StateEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

nine ↔ int
getter/setter pair
space ↔ int
getter/setter pair
zero ↔ int
getter/setter pair