StateEntry class

Constructors

StateEntry(String piece, SquarePosition position, ChessState state)

Properties

hashCode → int
The hash code for this object.
no setterinherited
piece → String
final
position → SquarePosition
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → ChessState
final

Methods

getKey() → String
lastPosition() → SquarePosition?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited