DropIndicatorArgs class

Constructors

DropIndicatorArgs({required double size, required Color color, dynamic radius})

Properties

color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
radius → BorderRadius
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited