HintMap class

Constructors

HintMap({String key = ""})

Properties

board ↔ Map<int, Map<int, HintBuilder?>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHint(int rank, int file) → HintBuilder?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int rank, int file, HintBuilder? widget) → HintMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited