SquareLocation class

Constructors

SquareLocation(int rank, int file)
SquareLocation.fromString(String square)

Properties

file → int
final
fileIndex → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
rank → int
final
rankIndex → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited