Arrow class
Properties
-
color
→ Color
-
The arrow's colour. Its alpha is the arrow's opacity: the arrow is drawn
as one path, so a translucent arrow has an even tint, tip included.
final
-
from
→ SquareLocation
-
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
to
→ SquareLocation
-
final
-
width
→ double?
-
Stroke width in logical pixels. Null draws the default 4.
final
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited