color property
The arrow's colour. Its alpha is the arrow's opacity: the arrow is drawn as one path, so a translucent arrow has an even tint, tip included.
Implementation
final Color color;
The arrow's colour. Its alpha is the arrow's opacity: the arrow is drawn as one path, so a translucent arrow has an even tint, tip included.
final Color color;